@@ -1,4 +1,5 @@
 from eesr.analysis.util import ensure_freq
-from eesr.analysis.opendc_preprocess import preprocess
+from eesr.analysis.opendc_preprocess import process
 from eesr.analysis.entsoe_caching import cached_query_crossborder_flows, cached_query_generation, cached_query_wind_and_solar_forecast
 from eesr.analysis.grid import GridAnalysis, fetch_generation_forecast_csv
+from eesr.analysis.opendc_preprocess import process
\ No newline at end of file
