@@ -1,7 +1,7 @@
 import pandas as pd
 import numpy as np
 
-def preprocess(path, offset_time : pd.Timestamp = None, tz="Europe/Amsterdam", PUE=1.59):
+def process(path, offset_time : pd.Timestamp = None, tz="Europe/Amsterdam", PUE=1.5):
 
     joule_to_kWh = lambda x: np.longdouble(x / (3.6e6))
 
@@ -20,17 +20,14 @@ def preprocess(path, offset_time : pd.Timestamp = None, tz="Europe/Amsterdam", P
     
     df['timestamp'] = pd.to_datetime(df['timestamp'], unit='ms')
 
-    df['it_energy_total'] = joule_to_kWh(df['it_power_total'])
+    df['it_power_total'] = joule_to_kWh(df['it_power_total'])
 
-    df['dc_energy_total'] = df['it_energy_total'] * PUE
+    df['dc_power_total'] = df['it_power_total'] * PUE
     
-    df.rename(columns={'it_power_total':'it_energy_total'})
-    df.drop(columns=['it_power_total'])
-
     df.set_index('timestamp', inplace=True)
-    df = df.tz_localize(tz, ambiguous=True)
+    df = df.tz_localize(tz)
 
     if (offset_time - df.index[0]) > pd.Timedelta(0):
         df.index = df.index + pd.Timedelta(offset_time - df.index[0])
-    
+
     return df
\ No newline at end of file
